@@ -1,14 +1,11 @@
 # coding: utf-8
 
-import binascii
-import sys
 import time
-import serial
 
-from radicl import serial as rs
-from radicl.ui_tools import get_logger
+from .ui_tools import get_logger
+from .commands import MeasCMD, SystemCMD, SettingsCMD, FWUpdateCMD, AttributeCMD
 
-pca_id_list = ["UNKNOWN", "PB1", "PB2", "PB3"]
+PCA_ID_LIST = ["UNKNOWN", "PB1", "PB2", "PB3"]
 
 
 class RAD_API:
@@ -19,11 +16,17 @@ class RAD_API:
     def __init__(self, port, debug=False):
         self.port = port
         self.log = get_logger(__name__, debug=debug)
+        self._serial = None
+        self._hw_id = None
+        self._hw_id_str = None
+        self._hw_rev = None
+        self._fw_rev = None
+        self._full_fw_rev = None
 
     def __sendCommand(self, data):
         """
         Generic send function
-        Returns 1 of successfull, 0 otherwise
+        Returns 1 of successful, 0 otherwise
         """
 
         success = 0
@@ -43,7 +46,7 @@ class RAD_API:
     def __getResponse(self):
         """
         Generic read function
-        Returns 1 if successfull, 0 otherwise
+        Returns 1 if successful, 0 otherwise
         """
 
         success = 0
@@ -69,7 +72,7 @@ class RAD_API:
     def __send_receive(self, data, read_delay=0.05):
         """
         Generic send/receive function
-        Returns the response if successfull, empty result otherwise
+        Returns the response if successful, empty result otherwise
         """
         # Dynamic delay variable, increases with each failed loop
         delay_counter = 0.001
@@ -81,7 +84,7 @@ class RAD_API:
         ret = self.__sendCommand(data)
 
         if ret:
-            # The command was successfully sent. Now read the response
+            # The command was successfuly sent. Now read the response
             time.sleep(0.001)
             ret = self.__getResponse()
             # Read the response as long as we don't get anything back AND
@@ -162,37 +165,36 @@ class RAD_API:
         Returns 1 if the message is a valid response
         0 for data_len means that the payload length could be variable
         """
-
+        valid = 0
         length = len(message)
         if length >= 5:
             if message[2] == 0x02:
                 calc_len = message[4] + 5
                 # If a command was specified we need to check if it matches.
-                # If it is incorrect we will return immediately
-                if cmd is not None:
-                    if message[1] != cmd:
-                        return 0
+                # If it is incorrect, the response is invalid
+                if message[1] == cmd:
+                    valid = 1
                 # If a data length was specified we need to check if it
                 # matches the message's data payload length. If it is incorrect
                 # we will return immediately
                 if (data_len is not None) and (data_len != 0):
-                    if message[4] != data_len:
-                        return 0
+                    if message[4] == data_len:
+                        valid = valid * 1
+
                 # If we get here then we have passed the additional
                 # specified checks. Finally, check if the overall length
                 # matches (integrity check)
                 if length == calc_len:
                     # The length is correct
-                    return 1
+                    valid = valid * 1
                 else:
                     # Not a response or incorrect length
-                    return 0
+                    valid = 0
+
             elif (message[2] == 0x06) and (length == 261):
-                return 1
-            else:
-                return 0
-        else:
-            return 0
+                valid = 1
+
+        return valid
 
     def __getNumPayloadBytes(self, message):
         """
@@ -283,29 +285,30 @@ class RAD_API:
         """
 
         if response is None:
-            return {'status': 0, 'errorCode': None, 'data': None}
+            result = {'status': 0, 'errorCode': None, 'data': None}
 
         elif (self.__isResponse(response, expected_command,
                                 num_expected_payload_bytes)):
-            return {'status': 1, 'errorCode': None,
-                    'data': response[-(
-                        self.__getNumPayloadBytes(response)):]}
+            result = {'status': 1, 'errorCode': None,
+                      'data': response[-(
+                          self.__getNumPayloadBytes(response)):]}
 
         elif (self.__isPushMessage(response, expected_command,
                                    num_expected_payload_bytes)):
-            return {'status': 1, 'errorCode': None,
-                    'data': response[-(
-                        self.__getNumPayloadBytes(response)):]}
+            result = {'status': 1, 'errorCode': None,
+                      'data': response[-(
+                          self.__getNumPayloadBytes(response)):]}
 
         elif self.__isACK(response):
-            return {'status': 1, 'errorCode': None, 'data': None}
+            result = {'status': 1, 'errorCode': None, 'data': None}
 
         elif self.__isNACK(response):
             nack_value = self.__getNACKValue(response)
-            return {'status': 0, 'errorCode': nack_value, 'data': None}
+            result = {'status': 0, 'errorCode': nack_value, 'data': None}
 
         else:
-            return {'status': 0, 'errorCode': None, 'data': None}
+            result = {'status': 0, 'errorCode': None, 'data': None}
+        return result
 
     # ********************
     # * PUBLIC FUNCTIONS *
@@ -318,36 +321,83 @@ class RAD_API:
         """
         self.port.writePort([0x21])
 
+    @property
+    def hw_id(self):
+        """
+        Gets the hardware id
+        """
+        if self._hw_id is None:
+            ret = self.getHWID()
+            self._hw_id = ret['data']
+        return self._hw_id
+
+    @property
+    def hw_id_str(self):
+        """
+        Gets the hardware id string
+        """
+        if self._hw_id_str is None:
+            if self.hw_id < len(PCA_ID_LIST):
+                self._hw_id_str = PCA_ID_LIST[self.hw_id]
+        return self._hw_id_str
+
+    @property
+    def hw_rev(self):
+        """
+        Gets the hardware revision
+        """
+        if self._hw_rev is None:
+            ret = self.getHWREV()
+            self._hw_rev = ret['data']
+        return self._hw_rev
+
+    @property
+    def fw_rev(self):
+        """
+        Gets the hardware id
+        """
+        if self._fw_rev is None:
+            ret = self.getFWREV()
+            self._fw_rev = ret['data']
+        return self._fw_rev
+
+    @property
+    def full_fw_rev(self):
+        """
+        Gets the hardware id
+        """
+        if self._full_fw_rev is None:
+            ret = self.getFullFWREV()
+            self._full_fw_rev = ret['data']
+        return self._full_fw_rev
+
+    @property
+    def serial(self):
+        """
+        Gets the serial string
+        """
+        if self._serial is None:
+            self._serial = self.getSerialNumber()
+        return self._serial
+
     def Identify(self):
         """
         Identifies the connected device
         Returns 1 if a valid device was detected
         """
         self.log.debug("Retrieving probe information...")
-        ret = self.getHWID()
-        self.hw_id = ret['data']
-        time.sleep(0.5)
-        ret = self.getHWREV()
-        self.hw_rev = ret['data']
-        time.sleep(0.5)
-        ret = self.getFWREV()
-        self.fw_rev = ret['data']
-        time.sleep(0.5)
-        ret = self.getFullFWREV()
-        self.full_fw_rev = ret['data']
 
         if self.hw_id is not None:
-            if self.hw_id < len(pca_id_list):
+            if self.hw_id < len(PCA_ID_LIST):
+                id_msg = f"Attached device: {self.hw_id_str}, " \
+                         f"Revision={self.hw_rev}, "
+
                 if self.full_fw_rev is not None:
-                    self.log.info("Attached device: %s, Rev=%s, FW=%s" %
-                                  (pca_id_list[self.hw_id],
-                                   self.hw_rev,
-                                   self.full_fw_rev))
+                    id_msg += f"Firmware = {self.full_fw_rev}"
                 else:
-                    self.log.info("Attached device: %s, Rev=%s, FW=%s" %
-                                  (pca_id_list[self.hw_id],
-                                   self.hw_rev,
-                                   format(self.fw_rev, '.02f')))
+                    id_msg += f"Firmware = {self.fw_rev}"
+
+                self.log.info(id_msg)
                 return 1
 
             else:
@@ -358,21 +408,6 @@ class RAD_API:
             self.log.warning("Invalid response to ID request")
             return 0
 
-    def HWID(self):
-        return self.hw_id
-
-    def HWID_String(self):
-        return pca_id_list[self.hw_id]
-
-    def HWRev(self):
-        return self.hw_rev
-
-    def FWRev(self):
-        return self.fw_rev
-
-    def FullFWRev(self):
-        return self.full_fw_rev
-
     # ***************************
     # ***** BASIC COMMANDS ******
     # ***************************
@@ -380,19 +415,20 @@ class RAD_API:
         """
         Queries the board's serial number
         """
-        response = self.__send_receive([0x9F, 0x04, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x04, 8)
+        code = AttributeCMD.SERIAL.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 8)
 
     def getHWID(self):
         """
         Queries the board's HW ID
         """
+        code = AttributeCMD.HW_ID.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        ret_val = self.__EvaluateAndReturn(response, code, 1)
 
-        response = self.__send_receive([0x9F, 0x01, 0x00, 0x00, 0x00])
-        ret_val = self.__EvaluateAndReturn(response, 0x01, 1)
         if ret_val['status'] == 1:
-            byte_arr = ret_val['data']
-            data = int.from_bytes(byte_arr, byteorder='little')
+            data = int.from_bytes(ret_val['data'], byteorder='little')
             ret_val['data'] = data
 
         return ret_val
@@ -401,12 +437,12 @@ class RAD_API:
         """
         Queries the board's HW revision
         """
-
-        response = self.__send_receive([0x9F, 0x02, 0x00, 0x00, 0x00])
-        ret_val = self.__EvaluateAndReturn(response, 0x02, 1)
+        code = AttributeCMD.HW_REV.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        ret_val = self.__EvaluateAndReturn(response, code, 1)
         if ret_val['status'] == 1:
             byte_arr = ret_val['data']
-            data = int.from_bytes(byte_arr, byteorder='little')
+            data = int.from_bytes(ret_val['data'], byteorder='little')
             ret_val['data'] = data
 
         return ret_val
@@ -415,13 +451,12 @@ class RAD_API:
         """
         Queries the board's FW revision in MAJOR.MINOR format
         """
-
-        response = self.__send_receive([0x9F, 0x03, 0x00, 0x00, 0x00])
-        ret_val = self.__EvaluateAndReturn(response, 0x03, 2)
+        code = AttributeCMD.FW_REV.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        ret_val = self.__EvaluateAndReturn(response, code, 2)
         if ret_val['status'] == 1:
-            value = ret_val['data']
-            major = value[0]  # value[-2]
-            minor = value[1]  # value[-1]
+            major = ret_val['data'][0]  # value[-2]
+            minor = ret_val['data'][1]  # value[-1]
             fw_rev = major + minor / 100
             ret_val['data'] = fw_rev
         return ret_val
@@ -430,8 +465,9 @@ class RAD_API:
         """
         Queries the board's FW revision in the full A.B.C.D format
         """
-        response = self.__send_receive([0x9F, 0x09, 0x00, 0x00, 0x00])
-        ret_val = self.__EvaluateAndReturn(response, 0x09, 4)
+        code = AttributeCMD.FULL_FW_REV.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        ret_val = self.__EvaluateAndReturn(response, code, 4)
         if ret_val['status'] == 1:
             value = ret_val['data']
             rev_string = str(value[0]) + "." + str(value[1]) + \
@@ -443,21 +479,22 @@ class RAD_API:
         """
         Starts the bootloader
         """
-
-        response = self.__send_receive([0x9F, 0x05, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x05, 0)
+        code = SystemCMD.START_BOOTLOADER.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def getSystemStatus(self):
         """
         Queries the system status
         """
-
-        response = self.__send_receive([0x9F, 0x06, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x06, 4)
+        code = SettingsCMD.STATUS.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def getRunState(self):
-        response = self.__send_receive([0x9F, 0x07, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x07, 1)
+        code = SystemCMD.STATE.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     # ***************************************
     # ***** SENSOR/MEASUREMENT COMMANDS *****
@@ -467,233 +504,237 @@ class RAD_API:
         """
         Queries the state of the measurement state machine
         """
-
-        response = self.__send_receive([0x9F, 0x40, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x40, 1)
+        code = MeasCMD.STATE.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasReset(self):
         """
         Resets the measurement state machine
-        Returns 1 if successfull
+        Returns 1 if successful
         """
-
-        response = self.__send_receive([0x9F, 0x41, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x41, 0)
+        code = MeasCMD.RESET.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasStart(self):
         """
         Starts a measurement
         Returns 1 if successful
         """
-
-        response = self.__send_receive([0x9F, 0x42, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x42, 0)
+        code = MeasCMD.START.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasStop(self):
         """
         Stops a measurement
-        Returns 1 if successfull
+        Returns 1 if successful
         """
-
-        response = self.__send_receive([0x9F, 0x43, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x43, 0)
+        code = MeasCMD.STOP.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetNumSegments(self, buffer_id):
         """
         Queries the number of data segments for a particular data buffer
         """
-        message = [0x9F, 0x44, 0x00, 0x00, 0x01]
+        code = MeasCMD.NUM_SEGMENTS.cmd
+        message = [0x9F, code, 0x00, 0x00, 0x01]
         message.extend(buffer_id.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x44, 4)
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasReadDataSegment(self, buffer_id, numPacket):
         """
         Reads a specific data segment of a specific data buffer
         """
-
-        message = [0x9F, 0x45, 0x00, 0x00, 0x05]
+        code = MeasCMD.DATA_SEGMENT.cmd
+        message = [0x9F, code, 0x00, 0x00, 0x05]
         message.extend(buffer_id.to_bytes(1, byteorder='little'))
         message.extend(numPacket.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
 
         # Check if only the command matches. The length may be variable
-        return self.__EvaluateAndReturn(response, 0x45, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetSamplingRate(self):
         """
         Reads/Returns the IR sampling rate
         """
-
-        response = self.__send_receive([0x9F, 0x46, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x46, 4)
+        code = SettingsCMD.SAMPLING_RATE.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasSetSamplingRate(self, sampling_rate):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
         helpme - Sets the sensor sampling rate
         """
-
-        message = [0x9F, 0x46, 0x01, 0x00, 0x04]
+        code = SettingsCMD.SAMPLING_RATE.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(sampling_rate.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x46, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetZPFO(self):
         """
         Reads/returns the Zero Phase Filter Order used on the depth data.
         """
-
-        response = self.__send_receive([0x9F, 0x47, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x47, 4)
+        code = SettingsCMD.ZPFO.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasSetZPFO(self, zpfo):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
         helpme - Set the Zero Phase Filter Order used on the depth data.
         """
-
-        message = [0x9F, 0x47, 0x01, 0x00, 0x04]
+        code = SettingsCMD.ZPFO.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(zpfo.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x47, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetPPMM(self):
         """
         Reads/returns the Points per millimeter parameter
         """
-
-        response = self.__send_receive([0x9F, 0x48, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x48, 1)
+        code = SettingsCMD.PPMM.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetPPMM(self, ppmm):
         """
         helpme - Sets the Points per millimeter parameter
         """
-
-        message = [0x9F, 0x48, 0x01, 0x00, 0x01]
+        code = SettingsCMD.PPMM.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x01]
         message.extend(ppmm.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x48, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetALG(self):
         """
         Reads/Returns the algorithm (1 - depth corrected, 2 for timeseries only)
         parameter
         """
-
-        response = self.__send_receive([0x9F, 0x49, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x49, 1)
+        code = SettingsCMD.ALG.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetALG(self, alg):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
         helpme - Sets the algorithm (1 - depth corrected, 2 for timeseries only)
         """
-
-        message = [0x9F, 0x49, 0x01, 0x00, 0x01]
+        code = SettingsCMD.ALG.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x01]
         message.extend(alg.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x49, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetAPPP(self):
         """
         Reads the APPP parameter
         """
-
-        response = self.__send_receive([0x9F, 0x4A, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x4A, 1)
+        code = SettingsCMD.APPP.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetAPPP(self, appp):
         """
-        Returns status=1 if successfull, status=0 otherwise
-
+        Returns status=1 if successful, status=0 otherwise
         helpme - Sets the APPP parameter which smooths the timeseries data
-
         """
-
-        message = [0x9F, 0x4A, 0x01, 0x00, 0x01]
+        code = SettingsCMD.APPP.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x01]
         message.extend(appp.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x4A, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetTCM(self):
         """
         Reads the TCM parameter
         """
-
-        response = self.__send_receive([0x9F, 0x4B, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x4B, 1)
+        code = SettingsCMD.TCM.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetTCM(self, tcm):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
         helpme - Sets the Temperature correction method for the barometer data
 
         """
+        code = SettingsCMD.TCM.cmd
 
-        message = [0x9F, 0x4B, 0x01, 0x00, 0x01]
+        message = [0x9F, code, 0x01, 0x00, 0x01]
         message.extend(tcm.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x4B, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetUserTemp(self):
         """
-        Reads the user set tempreature
+        Reads the user set temperature
         """
-
-        response = self.__send_receive([0x9F, 0x4C, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x4C, 4)
+        code = SettingsCMD.USERTEMP.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasSetUserTemp(self, user_temp):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
-        helpme - Set the user specifed temperature for TCM=3
+        helpme - Set the user specified temperature for TCM=3
         """
-        message = [0x9F, 0x4C, 0x01, 0x00, 0x04]
+        code = SettingsCMD.USERTEMP.cmd
+
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(user_temp.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x4C, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetIR(self):
         """
         Reads the IR parameter
 
         """
-        response = self.__send_receive([0x9F, 0x4D, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x4D, 1)
+        code = SettingsCMD.IR.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetIR(self, ir):
         """
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
 
         helpme - Turns on the IR emitter
         """
-        message = [0x9F, 0x4D, 0x01, 0x00, 0x01]
+        code = SettingsCMD.IR.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x01]
         message.extend(ir.to_bytes(1, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x4D, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetCalibData(self, num_sensor):
         """
         Reads a sensor's calibration value
         """
-
-        message = [0x9F, 0x4E, 0x00, 0x00, 0x01]
+        code = SettingsCMD.CALIBDATA.cmd
+        message = [0x9F, code, 0x00, 0x00, 0x01]
         message.extend(num_sensor.to_bytes(1, byteorder='little'))
 
         response = self.__send_receive(message)
 
         # Expect 4 bytes back two for the low value and 2 for the high value
-        return self.__EvaluateAndReturn(response, 0x4E, 4)
+        return self.__EvaluateAndReturn(response, code, 4)
 
-    def MeasSetCalibData(
-        self, num_sensor, calibration_value_low, calibration_value_high):
+    def MeasSetCalibData(self, num_sensor, calibration_value_low,
+                         calibration_value_high):
         """
         Sets the probes calibration values. A high and low are set where the
         low. This is applied linearly and thus the low value should be the
@@ -704,100 +745,87 @@ class RAD_API:
 
         Args:
                 num_sensor: Integer indicating sensors 1,2,3, or 4.
-                low_value: 12-bit integer indicating the y intercept of a linear
+                calibration_value_low: 12-bit integer indicating the y intercept of a linear
                                    calibration
-                hi_value: 12-bit integer for the
+                calibration_value_high: 12-bit integer for the
 
         Returns:
                 status: 1 if successful, 0 otherwise
 
         helpme - Sets the calibration data for the specified sensor
         """
-
-        message = [0x9F, 0x4E, 0x01, 0x00, 0x05]
+        code = SettingsCMD.CALIBDATA.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x05]
 
         # Convert values each into a 1 and 2 bytes
         message.extend(num_sensor.to_bytes(1, byteorder='little'))
         message.extend(calibration_value_low.to_bytes(2, byteorder='little'))
         message.extend(calibration_value_high.to_bytes(2, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x4E, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetMeasTemp(self):
         """
         Reads the current temperature reading (from last measurement)
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        response = self.__send_receive([0x9F, 0x4F, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x4F, 0)
+        code = MeasCMD.TEMP.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetAccThreshold(self):
         """
         Reads the accelerometer threshold setting (an unsigned 32-bit integer in mG)
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-        response = self.__send_receive([0x9F, 0x50, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x50, 4)
+        code = SettingsCMD.ACCTHRESH.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasSetAccThreshold(self, threshold):
         """
         Sets the accelerometer threshold setting (accelerometer thresholding algorithm)
-        The parameter 'threshold' is an unsigned 32-bit (4-bytes) absolute value indicating the threshold in mG
-        A value of 0 turns the accelerometer thresholding algorithm off
-        Returns status=1 if successfull, status=0 otherwise
+        The parameter 'threshold' is an unsigned 32-bit (4-bytes) absolute value indicating the
+        threshold in mG A value of 0 turns the accelerometer thresholding algorithm off
+        Returns status=1 if successful, status=0 otherwise
         """
-        message = [0x9F, 0x50, 0x01, 0x00, 0x04]
+        code = SettingsCMD.ACCTHRESH.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(threshold.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x50, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetAccZPFO(self):
         """
-        Reads the accelerometer zero-phase filter order setting (post-processing filter for accelerometer thresholding algorithm)
-        Returns status=1 if successfull, status=0 otherwise
+        Reads the accelerometer zero-phase filter order setting (post-processing filter
+        for accelerometer thresholding algorithm) Returns status=1 if successful,
+        status=0 otherwise
         """
-        response = self.__send_receive([0x9F, 0x51, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x51, 4)
+        code = SettingsCMD.ACCZPFO.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 4)
 
     def MeasSetAccZPFO(self, zpfo):
         """
-        Sets the accelerometer zero-phase filter order setting (post-processing filter for accelerometer thresholding algorithm)
-        The parameter 'zpfo' is an unsigned 32-bit (4-bytes) value indicaing the filter order
-        A value of 0 turns the filtering off (filter is bypassed)
-        Returns status=1 if successfull, status=0 otherwise
+        Sets the accelerometer zero-phase filter order setting (post-processing filter
+        for accelerometer thresholding algorithm) The parameter 'zpfo' is an
+        unsigned 32-bit (4-bytes) value indicaing the filter order A value of 0
+        turns the filtering off (filter is bypassed) Returns status=1 if successful,
+        status=0 otherwise
         """
-        message = [0x9F, 0x51, 0x01, 0x00, 0x04]
+        code = SettingsCMD.ACCZPFO.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(zpfo.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x51, 0)
-
-    def MeasGetAccZPFO(self):
-        """
-        Reads the accelerometer zero-phase filter order setting (post-processing filter for accelerometer thresholding algorithm)
-        Returns status=1 if successfull, status=0 otherwise
-        """
-        response = self.__send_receive([0x9F, 0x51, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x51, 4)
-
-    def MeasSetAccZPFO(self, zpfo):
-        """
-        Sets the accelerometer zero-phase filter order setting (post-processing filter for accelerometer thresholding algorithm)
-        The parameter 'zpfo' is an unsigned 32-bit (4-bytes) value indicaing the filter order
-        A value of 0 turns the filtering off (filter is bypassed)
-        Returns status=1 if successfull, status=0 otherwise
-        """
-        message = [0x9F, 0x51, 0x01, 0x00, 0x04]
-        message.extend(zpfo.to_bytes(4, byteorder='little'))
-        response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x51, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def MeasGetAccRange(self):
         """
         gets the accelerometer range
         """
-        response = self.__send_receive([0x9F, 0x52, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0x52, 1)
+        code = SettingsCMD.ACCRANGE.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def MeasSetAccRange(self, abs_range_gs):
         """
@@ -807,12 +835,12 @@ class RAD_API:
             abs_range_gs: integer value for range e.g. 2 == +/-2g's
 
         Returns:
-
         """
-        message = [0x9F, 0x52, 0x01, 0x00, 0x04]
+        code = SettingsCMD.ACCRANGE.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(abs_range_gs.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0x52, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     # ******************************
     # ***** FW UPDATE COMMANDS *****
@@ -821,84 +849,84 @@ class RAD_API:
     def UpdateEnter(self):
         """
         Enters the FW Update FSM
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        response = self.__send_receive([0x9F, 0xF0, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0xF0, 0)
+        code = FWUpdateCMD.ENTER.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def UpdateGetState(self):
         """
         Gets the FW update FSM state
         """
-
-        response = self.__send_receive([0x9F, 0xF1, 0x00, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0xF1, 1)
+        code = FWUpdateCMD.STATE.cmd
+        response = self.__send_receive([0x9F, code, 0x00, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def UpdateWaitForStateChange(self, wait_time):
         """
         Waits for the state change message
         """
-
+        code = FWUpdateCMD.STATE.cmd
         response = self.__waitForMessage(wait_time, 6)
-        return self.__EvaluateAndReturn(response, 0xF1, 1)
+        return self.__EvaluateAndReturn(response, code, 1)
 
     def UpdateSetSize(self, num_packets, packet_size):
         """
         Sets the update size
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        message = [0x9F, 0xF2, 0x01, 0x00, 0x06]
+        code = FWUpdateCMD.SIZE.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x06]
         message.extend(num_packets.to_bytes(4, byteorder='little'))
         message.extend(packet_size.to_bytes(2, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0xF2, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def UpdateDownload_Short(self, data, crc8, packet_id):
         """
-        Downloads a 16-byte chunck of data
-        Returns status=1 if successfull, status=0 otherwise
+        Downloads a 16-byte chunk of data
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        message = [0x9F, 0xF3, 0x01, 0x00, 0x00]
+        code = FWUpdateCMD.DOWNLOAD.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x00]
         message[3] = crc8
         message[4] = len(data)
         message.extend(data)
         self.__sendCommand(message)
         response = self.__waitForMessage(20)
-        return self.__EvaluateAndReturn(response, 0xF3, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def UpdateDownload_Long(self, data, crc8, packet_id):
         """
         Downloads a 256-byte chunck of data
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        message = [0x9F, 0xF3, 0x07, 0x00, 0x00]
+        code = FWUpdateCMD.DOWNLOAD.cmd
+        message = [0x9F, code, 0x07, 0x00, 0x00]
         message[3] = crc8
         message[4] = 0
         message.extend(data)
         self.__sendCommand(message)
         response = self.__waitForMessage(20)
-        return self.__EvaluateAndReturn(response, 0xF3, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def UpdateSetCRC(self, crc32):
         """
         Sets the CRC32 of the FW image
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        message = [0x9F, 0xF4, 0x01, 0x00, 0x04]
+        code = FWUpdateCMD.CRC.cmd
+        message = [0x9F, code, 0x01, 0x00, 0x04]
         message.extend(crc32.to_bytes(4, byteorder='little'))
         response = self.__send_receive(message)
-        return self.__EvaluateAndReturn(response, 0xF4, 0)
+        return self.__EvaluateAndReturn(response, code, 0)
 
     def UpdateClose(self):
         """
         Closes the FW update FSM
-        Returns status=1 if successfull, status=0 otherwise
+        Returns status=1 if successful, status=0 otherwise
         """
-
-        response = self.__send_receive([0x9F, 0xF5, 0x01, 0x00, 0x00])
-        return self.__EvaluateAndReturn(response, 0xF5, 0)
+        code = FWUpdateCMD.CLOSE.cmd
+        response = self.__send_receive([0x9F, code, 0x01, 0x00, 0x00])
+        return self.__EvaluateAndReturn(response, code, 0)
